%define libname %(echo %{name} | sed -e 's/^ocaml-//')

Name:           ocaml-lambda-term
Version:        2.0.3
Release:        %mkrel 4
Summary:        Terminal manipulation library for OCaml
License:        BSD-3-clause
Group:          Development/OCaml
URL:            https://github.com/ocaml-community/lambda-term/
Source0:        https://github.com/ocaml-community/lambda-term/releases/download/%{version}/lambda-term-%{version}.tbz
BuildRequires:  ocaml-camomile-devel
BuildRequires:  ocaml-findlib-devel
BuildRequires:  ocaml-lwt-devel
BuildRequires:  ocaml-lwt-react-devel
BuildRequires:	ocaml-lwt_log-devel
BuildRequires:  ocaml-react-devel
BuildRequires:  ocaml-zed-devel
BuildRequires:  ocaml-result-devel
# as deps of deps:
BuildRequires:  ocaml-mmap-devel
BuildRequires:  ocaml-charinfo-width-devel
BuildRequires:  ocaml-ocplib-endian-devel

BuildRequires:  pkgconfig(libev)

# opam-installer is needed for "jbuilder install" to work.
BuildRequires:  ocaml-dune, opam

Requires:       ocaml-camomile
Requires:       ocaml-zed
Requires:       ocaml-lwt

%description
Lambda-term is a cross-platform library for manipulating the
terminal. It provides an abstraction for keys, mouse events, colors,
as well as a set of widgets to write curses-like applications.

The main objective of lambda-term is to provide a higher level
functional interface to terminal manipulation than, for example,
ncurses, by providing a native OCaml interface instead of bindings to
a C library.

Lambda-term integrates with zed to provide text edition facilities in
console applications.

%package        devel
Summary:        Development files for %{name}
Group:          Development/OCaml
Requires:       %{name} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and signature files for
developing applications that use %{name}.

%prep
%setup -q -n lambda-term-%{version}

%build
%global _smp_ncpus_max 8
# It might be nice to have a %jbuilder macro that just does this.
dune build -p lambda-term %{?_smp_mflags}

%install
export OCAMLFIND_DESTDIR=%{buildroot}%{_libdir}/ocaml
mkdir -p $OCAMLFIND_DESTDIR
dune install --destdir=%{buildroot}

# Hmm... the above needs refinement. Remove spurious doc files.
rm -rf %{buildroot}%{_prefix}/doc
# Also, remove ml files that jbuilder seems to want to install.
rm -rf %{buildroot}%{_libdir}/ocaml/%{libname}/*.ml

# Makes *.cmxs executable such that they will be stripped.
find %{buildroot} -name '*.cmxs' -exec chmod 0755 {} \;

%files
%doc README.md CHANGES.md
%license LICENSE
%{_bindir}/lambda-term-actions
%{_datadir}/lambda-term*
%dir %{_libdir}/ocaml/lambda-term
%{_libdir}/ocaml/lambda-term/META
%{_libdir}/ocaml/lambda-term/*dune*
%{_libdir}/ocaml/lambda-term/*.cmi
%{_libdir}/ocaml/lambda-term/*.cma
%{_libdir}/ocaml/lambda-term/*.cmxs
%{_libdir}/ocaml/lambda-term/opam
%{_libdir}/ocaml/stublibs/*.so*
%{_mandir}/man1/*
%{_mandir}/man5/*

%files devel
%doc examples/ tests/
%{_libdir}/ocaml/lambda-term/*.a
%{_libdir}/ocaml/lambda-term/*.cmxa
%{_libdir}/ocaml/lambda-term/*.cmx
%{_libdir}/ocaml/lambda-term/*.mli
%{_libdir}/ocaml/lambda-term/*.cmt
%{_libdir}/ocaml/lambda-term/*.cmti


%changelog
* Sun Jan 10 2021 pterjan <pterjan> 2.0.3-4.mga8
+ Revision: 1670731
- Rebuild to generate ocamlx provides

* Fri Feb 28 2020 umeabot <umeabot> 2.0.3-3.mga8
+ Revision: 1551882
- Rebuild for ocaml 4.10.0 final

* Thu Feb 20 2020 umeabot <umeabot> 2.0.3-2.mga8
+ Revision: 1545188
- Mageia 8 Mass Rebuild

* Mon Jan 27 2020 tv <tv> 2.0.3-1.mga8
+ Revision: 1484154
- try to limit to 8 CPUs
- new release + rebuild for ocaml-4.10

* Thu Oct 25 2018 daviddavid <daviddavid> 1.13-2.mga7
+ Revision: 1325488
- rebuild for new ocaml 4.07.1

* Thu Oct 11 2018 pterjan <pterjan> 1.13-1.mga7
+ Revision: 1319717
- Update to 1.13
+ daviddavid <daviddavid>
- rebuild for new ocaml-lwt 4.1.0

* Sun Sep 23 2018 umeabot <umeabot> 1.12.0-4.mga7
+ Revision: 1299889
- Mageia 7 Mass Rebuild

* Fri Jul 06 2018 daviddavid <daviddavid> 1.12.0-3.mga7
+ Revision: 1242104
- rebuild against current ocaml stack

* Tue Mar 27 2018 daviddavid <daviddavid> 1.12.0-2.mga7
+ Revision: 1212733
- rebuild for new ocaml-react 1.2.1

* Fri Mar 16 2018 daviddavid <daviddavid> 1.12.0-1.mga7
+ Revision: 1209879
- new version: 1.12.0
- switch to the jbuilder build system
+ tv <tv>
- rebuild for new ocaml

* Fri Oct 13 2017 daviddavid <daviddavid> 1.9-3.mga7
+ Revision: 1171473
- rebuild for fixed ocaml (use standard ISO C99 types {u}uint{32,64}_t)

* Sun Jul 23 2017 daviddavid <daviddavid> 1.9-2.mga7
+ Revision: 1129488
- fix shared stubs libraries ocaml path (mga#21317)

* Wed Feb 17 2016 daviddavid <daviddavid> 1.9-1.mga6
+ Revision: 963628
- new version: 1.9
- update files list for devel subpackage

* Wed Feb 17 2016 daviddavid <daviddavid> 1.6-3.mga6
+ Revision: 963215
- rebuild for new ocaml

* Wed Oct 15 2014 umeabot <umeabot> 1.6-2.mga5
+ Revision: 741858
- Second Mageia 5 Mass Rebuild

* Tue Oct 07 2014 malo <malo> 1.6-1.mga5
+ Revision: 737265
- update to 1.6
+ umeabot <umeabot>
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 1.4-3.mga4
+ Revision: 536420
- Mageia 4 Mass Rebuild

* Mon Sep 23 2013 blue_prawn <blue_prawn> 1.4-2.mga4
+ Revision: 484270
- rebuild for ocaml-4.01.0

* Fri Aug 02 2013 blue_prawn <blue_prawn> 1.4-1.mga4
+ Revision: 462601
- updated to last version 1.4

* Sun Jan 13 2013 umeabot <umeabot> 1.3-2.mga3
+ Revision: 361434
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Oct 20 2012 malo <malo> 1.3-1.mga3
+ Revision: 308581
- update to 1.3
+ blue_prawn <blue_prawn>
- new rpm group for ocaml
- new rpm group for ocaml

* Fri Aug 03 2012 blue_prawn <blue_prawn> 1.2-1.mga3
+ Revision: 278059
- ocaml-camomile required by zed
- imported package ocaml-lambda-term

